@@ -9,7 +9,7 @@
 table = {}
 
 ---
----Given a list where all elements are strings or numbers, returns the string `list[i]..sep..list[i+1] ··· sep..list[j]`.
+---提供一个列表，其所有元素都是字符串或数字，返回字符串 `list[i]..sep..list[i+1] ··· sep..list[j]`。
 ---
 ---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.concat"])
 ---
@@ -22,7 +22,7 @@ table = {}
 function table.concat(list, sep, i, j) end
 
 ---
----Inserts element `value` at position `pos` in `list`.
+---在 `list` 的位置 `pos` 处插入元素 `value`。
 ---
 ---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.insert"])
 ---
@@ -34,7 +34,7 @@ function table.insert(list, pos, value) end
 
 ---@version <5.1
 ---
----Returns the largest positive numerical index of the given table, or zero if the table has no positive numerical indices.
+---返回给定表的最大正数索引，如果表没有正数索引，则返回零。
 ---
 ---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.maxn"])
 ---
@@ -45,7 +45,7 @@ function table.maxn(table) end
 
 ---@version >5.3
 ---
----Moves elements from table `a1` to table `a2`.
+---将元素从表 `a1` 移到表 `a2`。
 ---```lua
 ---a2[t],··· =
 ---a1[f],···,a1[e]
@@ -151,4 +151,33 @@ function table.foreachi(list, callback) end
 ---@deprecated
 function table.getn(list) end
 
+---@version JIT
+---
+---This creates a pre-sized table, just like the C API equivalent `lua_createtable()`. This is useful for big tables if the final table size is known and automatic table resizing is too expensive. `narray` parameter specifies the number of array-like items, and `nhash` parameter specifies the number of hash-like items. The function needs to be required before use.
+---```lua
+---    require("table.new")
+---```
+---
+---
+---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.new"])
+---
+---@param narray integer
+---@param nhash integer
+---@return table
+function table.new(narray, nhash) end
+
+---@version JIT
+---
+---This clears all keys and values from a table, but preserves the allocated array/hash sizes. This is useful when a table, which is linked from multiple places, needs to be cleared and/or when recycling a table for use by the same context. This avoids managing backlinks, saves an allocation and the overhead of incremental array/hash part growth. The function needs to be required before use.
+---```lua
+---    require("table.clear").
+---```
+---Please note this function is meant for very specific situations. In most cases it's better to replace the (usually single) link with a new table and let the GC do its work.
+---
+---
+---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.clear"])
+---
+---@param tab table
+function table.clear(tab) end
+
 return table
