@@ -165,8 +165,8 @@ end
 --- 设置文件文本
 ---@param uri uri
 ---@param text string
----@param isTrust boolean
----@param callback function
+---@param isTrust? boolean
+---@param callback? function
 function m.setText(uri, text, isTrust, callback)
     if not text then
         return
@@ -210,7 +210,7 @@ function m.setText(uri, text, isTrust, callback)
     file.cache = {}
     file.cacheActiveTime = math.huge
     m.globalVersion = m.globalVersion + 1
-    m.onWatch('version')
+    m.onWatch('version', uri)
     if create then
         m.onWatch('create', uri)
         m.onWatch('update', uri)
@@ -391,7 +391,6 @@ end
 --- 移除文件
 ---@param uri uri
 function m.remove(uri)
-    local originUri = uri
     local file = m.fileMap[uri]
     if not file then
         return
@@ -403,8 +402,8 @@ function m.remove(uri)
     m.fileCount     = m.fileCount - 1
     m.globalVersion = m.globalVersion + 1
 
-    m.onWatch('version')
-    m.onWatch('remove', originUri)
+    m.onWatch('version', uri)
+    m.onWatch('remove', uri)
 end
 
 --- 获取一个包含所有文件uri的数组
@@ -550,38 +549,6 @@ function m.getLastState(uri)
     return file.ast
 end
 
----设置文件的当前可见范围
----@param uri    uri
----@param ranges range[]
-function m.setVisibles(uri, ranges)
-    m.visible[uri] = ranges
-    m.onWatch('updateVisible', uri)
-end
-
----获取文件的当前可见范围
----@param uri uri
----@return table[]
-function m.getVisibles(uri)
-    local file = m.fileMap[uri]
-    if not file then
-        return nil
-    end
-    local ranges = m.visible[uri]
-    if not ranges or #ranges == 0 then
-        return nil
-    end
-    local visibles = {}
-    for i, range in ipairs(ranges) do
-        local startRow  = range.start.line
-        local finishRow = range['end'].line
-        visibles[i] = {
-            start  = guide.positionOf(startRow, 0),
-            finish = guide.positionOf(finishRow, 0),
-        }
-    end
-    return visibles
-end
-
 function m.getFile(uri)
     return m.fileMap[uri]
         or m.dllMap[uri]
